aboutsummaryrefslogtreecommitdiffstats
path: root/src/manager/gateway.h
diff options
context:
space:
mode:
authorMartin Willi <martin@strongswan.org>2007-09-26 14:02:21 +0000
committerMartin Willi <martin@strongswan.org>2007-09-26 14:02:21 +0000
commitc295d0eb4b11a024d1607f6a80275f372c345c08 (patch)
treeec3b578e771898bbf3ca35c1ae43e77ffdcea9d9 /src/manager/gateway.h
parenta9522e16003dd9f9fc7dc998a9017dbb41a65273 (diff)
downloadstrongswan-c295d0eb4b11a024d1607f6a80275f372c345c08.tar.bz2
strongswan-c295d0eb4b11a024d1607f6a80275f372c345c08.tar.xz
refactored strongswan manager
removed buggy request parsing code, use ClearSilvers CGI kit instead fixed CHILD_SA listing in manager (needs better design) using secure XML communication through unix sockets removed images with questionable (non-GPL) license
Diffstat (limited to 'src/manager/gateway.h')
-rw-r--r--src/manager/gateway.h22
1 files changed, 19 insertions, 3 deletions
diff --git a/src/manager/gateway.h b/src/manager/gateway.h
index 7b5d91045..d84f00038 100644
--- a/src/manager/gateway.h
+++ b/src/manager/gateway.h
@@ -24,6 +24,7 @@
#define GATEWAY_H_
#include <utils/host.h>
+#include <enumerator.h>
typedef struct gateway_t gateway_t;
@@ -39,7 +40,14 @@ struct gateway_t {
* @return allocated xml response string
*/
char* (*request)(gateway_t *this, char *xml);
-
+
+ /**
+ * @brief Query the list of IKE_SAs and all its children.
+ *
+ * @return enumerator over ikesa XML elements
+ */
+ enumerator_t* (*query_ikesalist)(gateway_t *this);
+
/**
* @brief Destroy a gateway instance.
*/
@@ -47,12 +55,20 @@ struct gateway_t {
};
/**
* @brief Create a gateway instance.
*
* @param name name of the gateway
* @param host gateway connection endpoint
* @param
*/
-gateway_t *gateway_create(char *name, host_t *host);
+gateway_t *gateway_create_tcp(char *name, host_t *host);
+
+/**
+ * @brief Create a gateway instance using a UNIX socket.
+ *
+ * @param name name of the gateway
+ * @param
+ */
+gateway_t *gateway_create_unix(char *name);
#endif /* GATEWAY_H_ */
@@ -47,12 +55,20 @@ struct gateway_t {
};
/**
- * @brief Create a gateway instance.
+ * @brief Create a gateway instance using a TCP connection.
*
* @param name name of the gateway